{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Terraform.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/terraform.xml and 'make bootstrap'.
module Skylighting.Syntax.Terraform (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Terraform.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rterraform.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKblocks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tterraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2built in functions\NUL\NUL\NUL\NUL\NUL\NUL\NULp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparseint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKindent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQregex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregexall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntrimprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntrimsuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttrimspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalltrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchunklist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcoalescelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflatten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlookup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmatchkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetintersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetsubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQslice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzipmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64decode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64encode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbase64gzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcsvdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njsondecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njsonencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextdecodebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextencodebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\turlencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nyamldecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nyamlencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabspath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npathexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfileexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afileset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftemplatefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64sha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64sha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbcrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfilebase64sha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfilebase64sha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afilemd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfilesha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilesha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilesha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrsadecrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuuidv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcidrhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcidrnetmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncidrsubnet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcidrsubnets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefaults\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnonsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtobool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtolist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btonumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomplex types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdynamic types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErequired_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmeta arguments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndepends_on\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfor_each\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlifecycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIprimitive types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspecial vars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstructural types\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtuple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsub blocks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprovisioner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2required_providers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abackend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH${\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInterpolation\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInterpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rInterpolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLErequired_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndepends_on\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfor_each\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlifecycle\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprovider\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bresource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tterraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abackend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprovisioner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2required_providers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aabspath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalltrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanytrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64decode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64encode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbase64gzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64sha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbase64sha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbcrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchunklist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcidrhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcidrnetmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncidrsubnet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcidrsubnets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcoalescelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcsvdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefaults\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfilebase64sha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfilebase64sha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfileexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afilemd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afileset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfilesha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilesha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfilesha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflatten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nformatlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKindent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njsondecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njsonencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlookup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmatchkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnonsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparseint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npathexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQregex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregexall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrsadecrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsetintersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetsubtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsha1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsha256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsha512\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQslice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftemplatefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextdecodebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtextencodebase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtobool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtolist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btonumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntrimprefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttrimspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntrimsuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\turlencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuuidv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nyamldecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nyamlencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzipmap\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtuple\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX...\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r!%&*+-/;<=>\\|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSThuck (denisdoria@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.tf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.tfvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
